==> org.eclipse.uml2.uml.source_4.1.0.v20130610-0712.jar: org/eclipse/uml2/uml/resource/XMI2UMLExtendedMetaData.java <==
/*
 * Copyright (c) 2006, 2011 IBM Corporation, Embarcadero Technologies, CEA, and others.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *   IBM - initial API and implementation
 *   Kenn Hussey (Embarcadero Technologies) - 204202
 *   Kenn Hussey (CEA) - 327039, 351774
 * 
 */
package org.eclipse.uml2.uml.resource;

import java.util.HashMap;
import java.util.Map;

import org.eclipse.emf.common.util.URI;
import org.eclipse.emf.ecore.EPackage;
import org.eclipse.emf.ecore.util.BasicExtendedMetaData;
import org.eclipse.uml2.uml.UMLPackage;

public class XMI2UMLExtendedMetaData
		extends BasicExtendedMetaData {

	protected static Map<URI, URI> uriMap = null;

	public static Map<URI, URI> getURIMap() {

		if (uriMap == null) {
			uriMap = new HashMap<URI, URI>();

			uriMap.put(URI.createURI(XMI2UMLResource.STANDARD_L3_PROFILE_URI),
				URI.createURI(UMLResource.STANDARD_L3_PROFILE_URI));
			uriMap.put(URI.createURI(XMI2UMLResource.STANDARD_L2_PROFILE_URI),
				URI.createURI(UMLResource.STANDARD_L2_PROFILE_URI));

			uriMap.put(
				URI.createURI(XMI2UMLResource.STANDARD_L3_PROFILE_2_4_URI),
				URI.createURI(UMLResource.STANDARD_L3_PROFILE_URI));
			uriMap.put(
				URI.createURI(XMI2UMLResource.STANDARD_L2_PROFILE_2_4_URI),
				URI.createURI(UMLResource.STANDARD_L2_PROFILE_URI));

			uriMap.put(
				URI.createURI(XMI2UMLResource.STANDARD_L3_PROFILE_2_2_URI),
				URI.createURI(UMLResource.STANDARD_L3_PROFILE_URI));
			uriMap.put(
				URI.createURI(XMI2UMLResource.STANDARD_L2_PROFILE_2_2_URI),
				URI.createURI(UMLResource.STANDARD_L2_PROFILE_URI));

			uriMap.put(
				URI.createURI(XMI2UMLResource.STANDARD_L3_PROFILE_2_1_1_URI),
				URI.createURI(UMLResource.STANDARD_L3_PROFILE_URI));
			uriMap.put(
				URI.createURI(XMI2UMLResource.STANDARD_L2_PROFILE_2_1_1_URI),
				URI.createURI(UMLResource.STANDARD_L2_PROFILE_URI));

			uriMap.put(
				URI.createURI(XMI2UMLResource.STANDARD_L3_PROFILE_2_1_URI),
				URI.createURI(UMLResource.STANDARD_L3_PROFILE_URI));
			uriMap.put(
				URI.createURI(XMI2UMLResource.STANDARD_L2_PROFILE_2_1_URI),
				URI.createURI(UMLResource.STANDARD_L2_PROFILE_URI));
		}

		return uriMap;
	}

	public XMI2UMLExtendedMetaData(EPackage.Registry registry) {
		super(registry);
	}

	@Override
	public String getNamespace(EPackage ePackage) {

		if (ePackage == UMLPackage.eINSTANCE) {
			return XMI2UMLResource.UML_METAMODEL_NS_URI;
		}

		String namespace = super.getNamespace(ePackage);
		return UMLResource.STANDARD_L2_PROFILE_NS_URI.equals(namespace)
			? XMI2UMLResource.STANDARD_L2_PROFILE_NS_URI
			: (UMLResource.STANDARD_L3_PROFILE_NS_URI.equals(namespace)
				? XMI2UMLResource.STANDARD_L3_PROFILE_NS_URI
				: namespace);
	}

	@Override
	public EPackage getPackage(String namespace) {

		return XMI2UMLResource.UML_METAMODEL_NS_URI.equals(namespace)
			|| XMI2UMLResource.UML_METAMODEL_2_4_NS_URI.equals(namespace)
			|| XMI2UMLResource.UML_METAMODEL_2_2_NS_URI.equals(namespace)
			|| XMI2UMLResource.UML_METAMODEL_2_1_1_NS_URI.equals(namespace)
			|| XMI2UMLResource.UML_METAMODEL_2_1_NS_URI.equals(namespace)
			? UMLPackage.eINSTANCE
			: super.getPackage(XMI2UMLResource.STANDARD_L2_PROFILE_NS_URI
				.equals(namespace)
				|| XMI2UMLResource.STANDARD_L2_PROFILE_2_4_NS_URI
					.equals(namespace)
				|| XMI2UMLResource.STANDARD_L2_PROFILE_2_2_NS_URI
					.equals(namespace)
				|| XMI2UMLResource.STANDARD_L2_PROFILE_2_1_1_NS_URI
					.equals(namespace)
				|| XMI2UMLResource.STANDARD_L2_PROFILE_2_1_NS_URI
					.equals(namespace)
				? UMLResource.STANDARD_L2_PROFILE_NS_URI
				: (XMI2UMLResource.STANDARD_L3_PROFILE_NS_URI.equals(namespace)
					|| XMI2UMLResource.STANDARD_L3_PROFILE_2_4_NS_URI
						.equals(namespace)
					|| XMI2UMLResource.STANDARD_L3_PROFILE_2_2_NS_URI
						.equals(namespace)
					|| XMI2UMLResource.STANDARD_L3_PROFILE_2_1_1_NS_URI
						.equals(namespace)
					|| XMI2UMLResource.STANDARD_L3_PROFILE_2_1_NS_URI
						.equals(namespace)
					? UMLResource.STANDARD_L3_PROFILE_NS_URI
					: namespace));
	}

}

==> org.eclipse.uml2.uml.source_5.0.1.v20140910-1354.jar: org/eclipse/uml2/uml/resource/XMI2UMLExtendedMetaData.java <==
/*
 * Copyright (c) 2006, 2014 IBM Corporation, Embarcadero Technologies, CEA, and others.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *   IBM - initial API and implementation
 *   Kenn Hussey (Embarcadero Technologies) - 204202
 *   Kenn Hussey (CEA) - 327039, 351774, 418466
 * 
 */
package org.eclipse.uml2.uml.resource;

import java.util.HashMap;
import java.util.Map;

import org.eclipse.emf.common.util.URI;
import org.eclipse.emf.ecore.EPackage;
import org.eclipse.emf.ecore.util.BasicExtendedMetaData;
import org.eclipse.uml2.uml.UMLPackage;

public class XMI2UMLExtendedMetaData
		extends BasicExtendedMetaData {

	protected static Map<URI, URI> uriMap = null;

	public static Map<URI, URI> getURIMap() {

		if (uriMap == null) {
			uriMap = new HashMap<URI, URI>();

			uriMap.put(URI.createURI(XMI2UMLResource.STANDARD_PROFILE_URI),
				URI.createURI(UMLResource.STANDARD_PROFILE_URI));

			uriMap.put(
				URI.createURI(XMI2UMLResource.STANDARD_L3_PROFILE_2_4_1_URI),
				URI.createURI(UMLResource.STANDARD_PROFILE_URI));
			uriMap.put(
				URI.createURI(XMI2UMLResource.STANDARD_L2_PROFILE_2_4_1_URI),
				URI.createURI(UMLResource.STANDARD_PROFILE_URI));

			uriMap.put(
				URI.createURI(XMI2UMLResource.STANDARD_L3_PROFILE_2_4_URI),
				URI.createURI(UMLResource.STANDARD_PROFILE_URI));
			uriMap.put(
				URI.createURI(XMI2UMLResource.STANDARD_L2_PROFILE_2_4_URI),
				URI.createURI(UMLResource.STANDARD_PROFILE_URI));

			uriMap.put(
				URI.createURI(XMI2UMLResource.STANDARD_L3_PROFILE_2_2_URI),
				URI.createURI(UMLResource.STANDARD_PROFILE_URI));
			uriMap.put(
				URI.createURI(XMI2UMLResource.STANDARD_L2_PROFILE_2_2_URI),
				URI.createURI(UMLResource.STANDARD_PROFILE_URI));

			uriMap.put(
				URI.createURI(XMI2UMLResource.STANDARD_L3_PROFILE_2_1_1_URI),
				URI.createURI(UMLResource.STANDARD_PROFILE_URI));
			uriMap.put(
				URI.createURI(XMI2UMLResource.STANDARD_L2_PROFILE_2_1_1_URI),
				URI.createURI(UMLResource.STANDARD_PROFILE_URI));

			uriMap.put(
				URI.createURI(XMI2UMLResource.STANDARD_L3_PROFILE_2_1_URI),
				URI.createURI(UMLResource.STANDARD_PROFILE_URI));
			uriMap.put(
				URI.createURI(XMI2UMLResource.STANDARD_L2_PROFILE_2_1_URI),
				URI.createURI(UMLResource.STANDARD_PROFILE_URI));
		}

		return uriMap;
	}

	public XMI2UMLExtendedMetaData(EPackage.Registry registry) {
		super(registry);
	}

	@Override
	public String getNamespace(EPackage ePackage) {

		if (ePackage == UMLPackage.eINSTANCE) {
			return XMI2UMLResource.UML_METAMODEL_NS_URI;
		}

		String namespace = super.getNamespace(ePackage);
		return UMLResource.STANDARD_PROFILE_NS_URI.equals(namespace)
			? XMI2UMLResource.STANDARD_PROFILE_NS_URI
			: namespace;
	}

	@Override
	public EPackage getPackage(String namespace) {

		return XMI2UMLResource.UML_METAMODEL_NS_URI.equals(namespace)
			|| XMI2UMLResource.UML_METAMODEL_2_4_1_NS_URI.equals(namespace)
			|| XMI2UMLResource.UML_METAMODEL_2_4_NS_URI.equals(namespace)
			|| XMI2UMLResource.UML_METAMODEL_2_2_NS_URI.equals(namespace)
			|| XMI2UMLResource.UML_METAMODEL_2_1_1_NS_URI.equals(namespace)
			|| XMI2UMLResource.UML_METAMODEL_2_1_NS_URI.equals(namespace)
			? UMLPackage.eINSTANCE
			: super.getPackage(XMI2UMLResource.STANDARD_PROFILE_NS_URI
				.equals(namespace)
				|| XMI2UMLResource.STANDARD_L2_PROFILE_2_4_1_NS_URI
					.equals(namespace)
				|| XMI2UMLResource.STANDARD_L2_PROFILE_2_4_NS_URI
					.equals(namespace)
				|| XMI2UMLResource.STANDARD_L2_PROFILE_2_2_NS_URI
					.equals(namespace)
				|| XMI2UMLResource.STANDARD_L2_PROFILE_2_1_1_NS_URI
					.equals(namespace)
				|| XMI2UMLResource.STANDARD_L2_PROFILE_2_1_NS_URI
					.equals(namespace)
				|| XMI2UMLResource.STANDARD_L3_PROFILE_2_4_1_NS_URI
					.equals(namespace)
				|| XMI2UMLResource.STANDARD_L3_PROFILE_2_4_NS_URI
					.equals(namespace)
				|| XMI2UMLResource.STANDARD_L3_PROFILE_2_2_NS_URI
					.equals(namespace)
				|| XMI2UMLResource.STANDARD_L3_PROFILE_2_1_1_NS_URI
					.equals(namespace)
				|| XMI2UMLResource.STANDARD_L3_PROFILE_2_1_NS_URI
					.equals(namespace)
				? UMLResource.STANDARD_PROFILE_NS_URI
				: namespace);
	}

}
